==> manaplus-1.1.2.20.tar.bz2: manaplus/src/net/messageout.cpp <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "net/messageout.h"

#include "net/packetcounters.h"

#include "log.h"

#include "utils/stringutils.h"

#include <cstring>
#include <string>

namespace Net
{

MessageOut::MessageOut(short id _UNUSED_):
    mData(0),
    mDataSize(0),
    mPos(0)
{
    PacketCounters::incOutPackets();
    DEBUGLOG("MessageOut");
}

void MessageOut::writeInt8(Sint8 value)
{
    DEBUGLOG("writeInt8: " + toString((int)value));
    expand(1);
    mData[mPos] = value;
    mPos += 1;
    PacketCounters::incOutBytes(1);
}

void MessageOut::writeString(const std::string &string, int length)
{
    DEBUGLOG("writeString: " + string);
    int stringLength = static_cast<int>(string.length());
    if (length < 0)
    {
        // Write the length at the start if not fixed
        writeInt16(static_cast<short>(stringLength));
        length = stringLength;
    }
    else if (length < stringLength)
    {
        // Make sure the length of the string is no longer than specified
        stringLength = length;
    }
    expand(length);

    // Write the actual string
    memcpy(mData + mPos, string.c_str(), stringLength);

    // Pad remaining space with zeros
    if (length > stringLength)
        memset(mData + mPos + stringLength, '\0', length - stringLength);

    mPos += length;
    PacketCounters::incOutBytes(length);
}

char *MessageOut::getData() const
{
    return mData;
}

unsigned int MessageOut::getDataSize() const
{
    return mDataSize;
}

}

==> manaplus-1.1.3.20.tar.bz2: manaplus/src/net/messageout.cpp <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "net/messageout.h"

#include "net/packetcounters.h"

#include "log.h"

#include "utils/stringutils.h"

#include <cstring>
#include <string>

namespace Net
{

MessageOut::MessageOut(short id _UNUSED_):
    mData(0),
    mDataSize(0),
    mPos(0)
{
    PacketCounters::incOutPackets();
    DEBUGLOG("MessageOut");
}

void MessageOut::writeInt8(Sint8 value)
{
    DEBUGLOG("writeInt8: " + toString(static_cast<int>(value)));
    expand(1);
    mData[mPos] = value;
    mPos += 1;
    PacketCounters::incOutBytes(1);
}

void MessageOut::writeString(const std::string &string, int length)
{
    DEBUGLOG("writeString: " + string);
    int stringLength = static_cast<int>(string.length());
    if (length < 0)
    {
        // Write the length at the start if not fixed
        writeInt16(static_cast<short>(stringLength));
        length = stringLength;
    }
    else if (length < stringLength)
    {
        // Make sure the length of the string is no longer than specified
        stringLength = length;
    }
    expand(length);

    // Write the actual string
    memcpy(mData + mPos, string.c_str(), stringLength);

    // Pad remaining space with zeros
    if (length > stringLength)
        memset(mData + mPos + stringLength, '\0', length - stringLength);

    mPos += length;
    PacketCounters::incOutBytes(length);
}

char *MessageOut::getData() const
{
    return mData;
}

unsigned int MessageOut::getDataSize() const
{
    return mDataSize;
}

}
